@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
 # w2do, a simple text-based todo manager
-# Copyright (C) 2008, 2009 Jaromir Hradilek
+# Copyright (C) 2008, 2009, 2010 Jaromir Hradilek
 
 # This program is  free software:  you can redistribute it and/or modify it
 # under  the terms  of the  GNU General Public License  as published by the
@@ -18,23 +18,29 @@
 use strict;
 use warnings;
 use locale;
-use Text::Wrap;
-use File::Copy;
 use File::Basename;
+use File::Copy;
 use File::Spec::Functions;
-use Term::ANSIColor;
 use Getopt::Long;
+use Term::ANSIColor;
+use Text::Wrap;
 
 # General script information:
 use constant NAME    => basename($0, '.pl');       # Script name.
-use constant VERSION => '2.2.2';                   # Script version.
+use constant VERSION => '2.3.0';                   # Script version.
 
 # General script settings:
 our $homedir         = $ENV{HOME}          || $ENV{USERPROFILE} || '.';
 our $savefile        = $ENV{W2DO_SAVEFILE} || catfile($homedir, '.w2do');
 our $backext         = '.bak';                     # Backup file extension.
 our $verbose         = 1;                          # Verbosity level.
-
+our $with_id         = 1;                          # Include ID?
+our $with_group      = 1;                          # Include group name?
+our $with_date       = 1;                          # Include due date?
+our $with_pri        = 1;                          # Include priority?
+our $with_state      = 1;                          # Include state?
+our $bare            = 0;                          # Leave out the table
+                                                   # header and separators?
 # Appearance settings:
 $Text::Wrap::columns = $ENV{W2DO_WIDTH}    || 75;  # Default table width.
 our $coloured        = 0;                          # Use colourded output?
@@ -69,6 +75,8 @@ sub exit_with_error {
 # Translate given date to YYYY-MM-DD string:
 sub date_to_string {
   my $time = shift || time;
+
+  # Decompose the given time:
   my @date = localtime($time);
 
   # Return the result:
@@ -308,6 +316,8 @@ sub purge_selection {
 # Get task list statistics:
 sub get_stats {
   my $stats  = shift || die 'Missing argument';
+
+  # Initialize required variables:
   my ($groups, $tasks, $undone) = (0, 0, 0);
 
   # Open the save file for reading:
@@ -346,6 +356,7 @@ sub get_stats {
 
 # Choose first available ID:
 sub choose_id {
+  # Initialize required variables:
   my @used   = ();
   my $chosen = 1;
 
@@ -369,6 +380,127 @@ sub choose_id {
   return $chosen;
 }
 
+# Compose progress bar:
+sub compose_progressbar {
+  my $percent = shift || 0;
+
+  # Decide which pointer to use:
+  my $pointer = ($percent > 0 && $percent < 100) ? '>' : '';
+
+  # Return the progress bar string:
+  return '[' . '=' x int($percent/10) . $pointer .
+         ' ' x ($percent ? (9 - int($percent/10)) : 10) . ']';
+}
+
+# Draw table header:
+sub draw_header {
+  # End here if the header is to be omitted:
+  return 1 if $bare;
+
+  # Prepare the header layout:
+  my $border = '='x ($Text::Wrap::columns - 1);
+  my $header = ' ';
+  my $indent = 5;
+
+  # Add enabled header items:
+  $header .= 'id    '       and $indent += 6  if $with_id;
+  $header .= 'group       ' and $indent += 12 if $with_group;
+  $header .= 'date        ' and $indent += 12 if $with_date;
+  $header .= 'pri  '        and $indent += 5  if $with_pri;
+  $header .= 'sta  '        and $indent += 5  if $with_state;
+  $header .= 'task' . ' 'x ($Text::Wrap::columns - 1 - $indent);
+
+  # Check whether to use colours:
+  unless ($coloured) {
+    # Display plain table header:
+    print "$border\n$header\n$border\n";
+  }
+  else {
+    # Display coloured table header:
+    print colored ($header, $headcol);
+    print "\n";
+  }
+
+  # Return success:
+  return 1;
+}
+
+# Draw table separator:
+sub draw_separator {
+  # End here if the separator is to be omitted:
+  return 1 if $bare;
+
+  # Prepare the separator layout:
+  my $separator = '-'x ($Text::Wrap::columns - 1);
+  my $header    = ' ';
+  my $indent    = 5;
+
+  # Add enabled header items:
+  $header .= 'id    '       and $indent += 6  if $with_id;
+  $header .= 'group       ' and $indent += 12 if $with_group;
+  $header .= 'date        ' and $indent += 12 if $with_date;
+  $header .= 'pri  '        and $indent += 5  if $with_pri;
+  $header .= 'sta  '        and $indent += 5  if $with_state;
+  $header .= 'task' . ' 'x ($Text::Wrap::columns - 1 - $indent);
+
+  # Check whether to use colours:
+  unless ($coloured) {
+    # Display plain separator:
+    print "$separator\n";
+  }
+  else {
+    # Display coloured separator:
+    print colored ($header, $headcol);
+    print "\n";
+  }
+
+  # Return success:
+  return 1;
+}
+
+# Draw table row:
+sub draw_row {
+  my ($id, $group, $date, $priority, $state, $task) = @_;
+
+  # Initialize required variables:
+  my $row    = ' ';
+  my $indent = 1;
+
+  # Add enabled items:
+  $row .= sprintf("%-4s  ", $id)       and $indent += 6  if $with_id;
+  $row .= sprintf("%-10s  ", $group)   and $indent += 12 if $with_group;
+  $row .= sprintf("%-10s  ", $date)    and $indent += 12 if $with_date;
+  $row .= sprintf(" %s   ", $priority) and $indent += 5  if $with_pri;
+  $row .= sprintf(" %s   ", $state)    and $indent += 5  if $with_state;
+
+  # Prepare the task entry:
+  $task =  wrap(' 'x $indent, ' 'x $indent, $task);
+  $task =~ s/\s+//;
+
+  # Add the task entry:
+  $row .= $task;
+
+  # Check whether to use colours:
+  unless ($coloured) {
+    # Display the task entry:
+    print "$row\n";
+  }
+  else {
+    # Set up colours:
+    print color $donecol  if $state eq 'f';
+    print color $todaycol if $state ne 'f' && $date eq 'today';
+
+    # Display the task entry:
+    print "$row\n";
+
+    # Reset colours:
+    print color 'reset';
+  }
+
+  # Return success:
+  return 1;
+}
+
 # Display usage information:
 sub display_help {
   my $NAME = NAME;
@@ -396,6 +528,10 @@ General options:
   --remove-date date       remove all items with selected due date
   --purge-date date        remove all finished items with selected due date
 
+  --change-pri priority    change all items with selected priority
+  --remove-pri priority    remove all items with selected priority
+  --purge-pri priority     remove all finished items with selected priority
+
   --change-old             change all items with passed due date
   --remove-old             remove all items with passed due date
   --purge-old              remove all finished items with passed due date
@@ -404,9 +540,10 @@ General options:
   --remove-all             remove all items from the task list
   --purge-all              remove all finished items from the task list
 
-  -U, --undo               revert last action
-  -G, --groups             display list of groups in the task list
-  -S, --stats              display detailed task list statistics
+  --undo                   revert last action
+  --groups                 display list of groups in the task list
+  --stats                  display detailed task list statistics
+
   -h, --help               display this help and exit
   -v, --version            display version information and exit
 
@@ -429,6 +566,12 @@ Additional options:
   -q, --quiet              avoid displaying messages that are not necessary
   -C, --colour             use coloured output instead of the default plain
                            text version
+  -b, --bare               do not display table header and separators
+  -I, --no-id              do not display ID column
+  -G, --no-group           do not display group column
+  -D, --no-date            do not display due date column
+  -P, --no-priority        do not display priority column
+  -S, --no-state           do not display state column
 END_HELP
 
   # Return success:
@@ -443,7 +586,7 @@ sub display_version {
   print << "END_VERSION";
 $NAME $VERSION
 
-Copyright (C) 2008, 2009 Jaromir Hradilek
+Copyright (C) 2008, 2009, 2010 Jaromir Hradilek
 This program is free software; see the source for copying conditions. It is
 distributed in the hope  that it will be useful,  but WITHOUT ANY WARRANTY;
 without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PAR-
@@ -456,6 +599,7 @@ END_VERSION
 
 # Display a list of groups in the task list:
 sub display_groups {
+  # Initialize required variables:
   my $stats = {};
 
   # Get task list statistics:
@@ -478,20 +622,9 @@ sub display_groups {
   return 1;
 }
 
-# Draw progress bar:
-sub draw_progressbar {
-  my $percent = shift || 0;
-
-  # Decide which pointer to use:
-  my $pointer = ($percent > 0 && $percent < 100) ? '>' : '';
-
-  # Return the progress bar string:
-  return '[' . '=' x int($percent/10) . $pointer .
-         ' ' x ($percent ? (9 - int($percent/10)) : 10) . ']';
-}
-
 # Display detailed task list statistics:
 sub display_statistics {
+  # Initialize required variables:
   my $stats = {};
   my ($bar, $per, $rat);
 
@@ -514,7 +647,7 @@ sub display_statistics {
     $per = int($stats->{$group}->{done} * 100 / $stats->{$group}->{tasks});
 
     # Prepare the progress bar:
-    $bar = draw_progressbar($per);
+    $bar = compose_progressbar($per);
 
     # Prepare the finished/all ratio:
     $rat = "($stats->{$group}->{done}/$stats->{$group}->{tasks})";
@@ -527,7 +660,7 @@ sub display_statistics {
   $per = $tasks ? int($done * 100 / $tasks) : 0;
 
   # Prepare the progress bar:
-  $bar = draw_progressbar($per);
+  $bar = compose_progressbar($per);
 
   # Prepare the finished/all ratio:
   $rat = "($done/$tasks)";
@@ -542,6 +675,8 @@ sub display_statistics {
 # Display items in the task list:
 sub display_tasks {
   my $args = shift;
+
+  # Initialize required variables:
   my @data;
 
   # Load matching tasks:
@@ -549,30 +684,15 @@ sub display_tasks {
 
   # Check whether the list is not empty:
   if (@data) {
-    my $current = '';
+    # Initialize required variables:
     my ($id, $group, $date, $priority, $state, $task);
-
-    # Prepare the table layout:
-    my $format  = " %-4s  %-10s  %-10s   %s    %s   %s\n";
-    my $caption = " id    group       date        pri  sta  task" .
-                  ' 'x ($Text::Wrap::columns - 45);
-    my $divider = '-'x  $Text::Wrap::columns;
-    my $border  = '='x  $Text::Wrap::columns;
-    my $indent  = ' 'x  41;
+    my $current = '';
 
     # Set up the line wrapper:
     $Text::Wrap::columns++;
 
-    # Check whether to use colours:
-    if ($coloured) {
-      # Display coloured table header:
-      print colored ($caption, $headcol);
-      print "\n";
-    }
-    else {
-      # Display plain table header:
-      print "$border\n$caption\n$border\n";
-    }
+    # Display the table header:
+    draw_header();
 
     # Process each task:
     foreach my $line (sort @data) {
@@ -582,18 +702,7 @@ sub display_tasks {
       # Check whether the group has changed:
       if (lc($1) ne $current) {
         # Display the divider unless the first group is being listed:
-        if ($group) {
-          # Check whether to use colours:
-          if ($coloured) {
-            # Display coloured table header:
-            print colored ($caption, $headcol);
-            print "\n";
-          }
-          else {
-            # Display divider:
-            print "$divider\n";
-          }
-        }
+        draw_separator() if $group;
 
         # Remember the current group:
         $current = lc($1);
@@ -610,18 +719,10 @@ sub display_tasks {
       $group    = $1;
       $priority = $3;
       $state    = ($4 eq 'f') ? '-' : 'f';
-      $task     =  wrap($indent, $indent, $5); $task =~ s/\s+//;
-
-      # Set up colours:
-      print color $donecol  if $coloured && $state eq 'f';
-      print color $todaycol if $coloured && $state ne 'f'
-                                         && $date  eq 'today';
+      $task     = $5;
 
       # Display the task entry:
-      printf($format, $id, $group, $date, $priority, $state, $task);
-
-      # Reset colours:
-      print color 'reset'   if $coloured;
+      draw_row($id, $group, $date, $priority, $state, $task);
     }
   }
   else {
@@ -660,6 +761,7 @@ sub add_task {
 
 # Change selected item in the task list:
 sub change_task {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected task:
@@ -674,6 +776,7 @@ sub change_task {
 
 # Remove selected item from the task list:
 sub remove_task {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected task:
@@ -688,6 +791,7 @@ sub remove_task {
 
 # Change all items in the selected group:
 sub change_group {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -702,6 +806,7 @@ sub change_group {
 
 # Remove all items in the selected group:
 sub remove_group {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -716,6 +821,7 @@ sub remove_group {
 
 # Remove all finished items in the selected group:
 sub purge_group {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -730,6 +836,7 @@ sub purge_group {
 
 # Change all items with selected due date:
 sub change_date {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -744,6 +851,7 @@ sub change_date {
 
 # Remove all items with the selected due date:
 sub remove_date {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -758,6 +866,7 @@ sub remove_date {
 
 # Remove all finished items with selected due date:
 sub purge_date {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -770,8 +879,54 @@ sub purge_date {
   return 1;
 }
 
+# Change all items with selected priority:
+sub change_priority {
+  # Initialize required variables:
+  my (@selected, @data);
+
+  # Load selected tasks:
+  load_selection(\@selected, \@data, { priority => shift }) or return 0;
+
+  # Change selected items:
+  change_selection(\@selected, \@data, shift) or return 0;
+
+  # Return success:
+  return 1;
+}
+
+# Remove all items with selected priority:
+sub remove_priority {
+  # Initialize required variables:
+  my (@selected, @data);
+
+  # Load selected tasks:
+  load_selection(\@selected, \@data, { priority => shift }) or return 0;
+
+  # Remove selected items:
+  remove_selection(\@selected, \@data) or return 0;
+
+  # Return success:
+  return 1;
+}
+
+# Remove all finished items with selected priority:
+sub purge_priority {
+  # Initialize required variables:
+  my (@selected, @data);
+
+  # Load selected tasks:
+  load_selection(\@selected, \@data, { priority => shift }) or return 0;
+
+  # Purge selected items:
+  purge_selection(\@selected, \@data) or return 0;
+
+  # Return success:
+  return 1;
+}
+
 # Change all items with passed due date:
 sub change_old {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -786,6 +941,7 @@ sub change_old {
 
 # Remove all items with passed due date:
 sub remove_old {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -800,6 +956,7 @@ sub remove_old {
 
 # Purge all items with passed due date:
 sub purge_old {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load selected tasks:
@@ -814,6 +971,7 @@ sub purge_old {
 
 # Change all items in the task list:
 sub change_all {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load all tasks:
@@ -828,6 +986,7 @@ sub change_all {
 
 # Remove all items from the task list:
 sub remove_all {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load all tasks:
@@ -842,6 +1001,7 @@ sub remove_all {
 
 # Remove all finished items from the task list:
 sub purge_all {
+  # Initialize required variables:
   my (@selected, @data);
 
   # Load all tasks:
@@ -945,49 +1105,65 @@ Getopt::Long::Configure('no_auto_abbrev', 'no_ignore_case', 'bundling');
 # Parse command line options:
 GetOptions(
   # Specifying options:
-  'task|t=s'       => sub { $args{task}     = $_[1] },
-  'group|g=s'      => sub { $args{group}    = $_[1] },
-  'date|d=s'       => sub { $args{date}     = $_[1] },
-  'priority|p=i'   => sub { $args{priority} = $_[1] },
-  'finished|f'     => sub { $args{state}    = 't' },
-  'unfinished|u'   => sub { $args{state}    = 'f' },
+  'task|t=s'             => sub { $args{task}     = $_[1] },
+  'group|g=s'            => sub { $args{group}    = $_[1] },
+  'date|d=s'             => sub { $args{date}     = $_[1] },
+  'priority|p=i'         => sub { $args{priority} = $_[1] },
+  'finished|f'           => sub { $args{state}    = 't' },
+  'unfinished|u'         => sub { $args{state}    = 'f' },
 
   # Additional options:
-  'quiet|q'        => sub { $verbose             = 0 },
-  'verbose|V'      => sub { $verbose             = 1 },
-  'plain|P'        => sub { $coloured            = 0 },
-  'colour|color|C' => sub { $coloured            = 1 },
-  'savefile|s=s'   => sub { $savefile            = $_[1] },
-  'width|w=i'      => sub { $Text::Wrap::columns = $_[1] },
+  'savefile|s=s'         => sub { $savefile            = $_[1] },
+  'width|w=i'            => sub { $Text::Wrap::columns = $_[1] },
+  'quiet|q'              => sub { $verbose             = 0 },
+  'verbose|V'            => sub { $verbose             = 1 },
+  'no-colour|no-color|X' => sub { $coloured            = 0 },
+  'colour|color|C'       => sub { $coloured            = 1 },
+  'no-bare|B'            => sub { $bare                = 0 },
+  'bare|b'               => sub { $bare                = 1 },
+  'no-id|I'              => sub { $with_id             = 0 },
+  'with-id'              => sub { $with_id             = 1 },
+  'no-group|G'           => sub { $with_group          = 0 },
+  'with-group'           => sub { $with_group          = 1 },
+  'no-date|D'            => sub { $with_date           = 0 },
+  'with-date'            => sub { $with_date           = 1 },
+  'no-priority|P'        => sub { $with_pri            = 0 },
+  'with-priority'        => sub { $with_pri            = 1 },
+  'no-state|S'           => sub { $with_state          = 0 },
+  'with-state'           => sub { $with_state          = 1 },
 
   # General options:
-  'list|l'         => sub { $action = 0 },
-  'add|a=s'        => sub { $action = 1;  $args{task} = $_[1] },
-  'change|c=i'     => sub { $action = 2;  $identifier = $_[1] },
-  'remove|r=i'     => sub { $action = 3;  $identifier = $_[1] },
+  'list|l'               => sub { $action = 0 },
+  'add|a=s'              => sub { $action = 1;  $args{task} = $_[1] },
+  'change|c=i'           => sub { $action = 2;  $identifier = $_[1] },
+  'remove|r=i'           => sub { $action = 3;  $identifier = $_[1] },
 
-  'change-group=s' => sub { $action = 12; $identifier = $_[1] },
-  'remove-group=s' => sub { $action = 13; $identifier = $_[1] },
-  'purge-group=s'  => sub { $action = 14; $identifier = $_[1] },
+  'change-group=s'       => sub { $action = 12; $identifier = $_[1] },
+  'remove-group=s'       => sub { $action = 13; $identifier = $_[1] },
+  'purge-group=s'        => sub { $action = 14; $identifier = $_[1] },
 
-  'change-date=s'  => sub { $action = 22; $identifier = $_[1] },
-  'remove-date=s'  => sub { $action = 23; $identifier = $_[1] },
-  'purge-date=s'   => sub { $action = 24; $identifier = $_[1] },
+  'change-date=s'        => sub { $action = 22; $identifier = $_[1] },
+  'remove-date=s'        => sub { $action = 23; $identifier = $_[1] },
+  'purge-date=s'         => sub { $action = 24; $identifier = $_[1] },
 
-  'change-old'     => sub { $action = 32 },
-  'remove-old'     => sub { $action = 33 },
-  'purge-old'      => sub { $action = 34 },
+  'change-pri=i'         => sub { $action = 32; $identifier = $_[1] },
+  'remove-pri=i'         => sub { $action = 33; $identifier = $_[1] },
+  'purge-pri=i'          => sub { $action = 34; $identifier = $_[1] },
 
-  'change-all'     => sub { $action = 42 },
-  'remove-all'     => sub { $action = 43 },
-  'purge-all'      => sub { $action = 44 },
+  'change-old'           => sub { $action = 42 },
+  'remove-old'           => sub { $action = 43 },
+  'purge-old'            => sub { $action = 44 },
 
-  'undo|U'         => sub { $action = 95 },
-  'groups|G'       => sub { $action = 96 },
-  'stats|S'        => sub { $action = 97 },
+  'change-all'           => sub { $action = 52 },
+  'remove-all'           => sub { $action = 53 },
+  'purge-all'            => sub { $action = 54 },
 
-  'help|h'         => sub { display_help();    exit 0 },
-  'version|v'      => sub { display_version(); exit 0 },
+  'undo'                 => sub { $action = 95 },
+  'groups'               => sub { $action = 96 },
+  'stats|stat'           => sub { $action = 97 },
+
+  'help|h'               => sub { display_help();    exit 0 },
+  'version|v'            => sub { display_version(); exit 0 },
 );
 
 # Detect superfluous options:
@@ -1018,6 +1194,13 @@ if (my $value = $args{priority}) {
   }
 }
 
+# Check the priority identifier:
+if ($action >= 32 && $action <= 34) {
+  unless ($identifier =~ /^[1-5]$/) {
+    exit_with_error("Invalid priority `$identifier'.", 22);
+  }
+}
+
 # Check the line width option:
 if ($Text::Wrap::columns < 75) {
   exit_with_error("Invalid line width `$Text::Wrap::columns'.", 22);
@@ -1065,26 +1248,38 @@ elsif ($action == 24) {
   purge_date($identifier) or exit 1;
 }
 elsif ($action == 32) {
+  # Change all items with selected priority:
+  change_priority($identifier, \%args) or exit 1;
+}
+elsif ($action == 33) {
+  # Remove all items with selected priority:
+  remove_priority($identifier) or exit 1;
+}
+elsif ($action == 34) {
+  # Remove all finished items with selected priority:
+  purge_priority($identifier) or exit 1;
+}
+elsif ($action == 42) {
   # Change all items with passed due date:
   change_old(\%args) or exit 1;
 }
-elsif ($action == 33) {
+elsif ($action == 43) {
   # Remove all items with passed due date:
   remove_old() or exit 1;
 }
-elsif ($action == 34) {
+elsif ($action == 44) {
   # Remove all finished items with passed due date:
   purge_old() or exit 1;
 }
-elsif ($action == 42) {
+elsif ($action == 52) {
   # Change all items in the task list:
   change_all(\%args) or exit 1;
 }
-elsif ($action == 43) {
+elsif ($action == 53) {
   # Remove all items from the task list:
   remove_all() or exit 1;
 }
-elsif ($action == 44) {
+elsif ($action == 54) {
   # Remove all finished items from the task list:
   purge_all() or exit 1;
 }
@@ -1128,7 +1323,7 @@ B<w2do> [I<options>]
 =head1 DESCRIPTION
 
 B<w2do> is a simple to use yet efficient command-line todo manager written
-in Perl 5.
+in Perl.
 
 =head1 OPTIONS
 
@@ -1184,6 +1379,19 @@ Remove all items with selected due I<date>.
 
 Remove all finished items with selected due I<date>.
 
+=item B<--change-pri> I<priority>
+
+Change all items with selected I<priority>. Further specifying options are
+required in order to take any effect.
+
+=item B<--remove-pri> I<priority>
+
+Remove all items with selected I<priority>.
+
+=item B<--purge-pri> I<priority>
+
+Remove all finished items with selected I<priority>.
+
 =item B<--change-old>
 
 Change all items with passed due date. Further specifying options are
@@ -1210,16 +1418,16 @@ Remove all items from the task list.
 
 Remove all finished items from the task list.
 
-=item B<-U>, B<--undo>
+=item B<--undo>
 
 Revert last action. When invoked, the data are restored from the backup
 file (i.e. C<~/.w2do.bak> by default), which is deleted at the same time.
 
-=item B<-G>, B<--groups>
+=item B<--groups>
 
 Display comma-delimited list of all groups in the task list.
 
-=item B<-S>, B<--stats>
+=item B<--stats>
 
 Display detailed task list statistics.
 
@@ -1291,10 +1499,58 @@ Display all messages; this is the default option.
 
 Use coloured output instead of the default plain text version.
 
-=item B<-P>, B<--plain>
+=item B<-X>, B<--no-colour>, B<--no-color>
 
 Use plain text output (no colours); this is the default option.
 
+=item B<-b>, B<--bare>
+
+Do not display table header and group separators.
+
+=item B<-B>, B<--no-bare>
+
+Display table header and group separators; the default option.
+
+=item B<-I>, B<--no-id>
+
+Do not display ID column in the listing.
+
+=item B<--with-id>
+
+Display ID column in the listing; the default option.
+
+=item B<-G>, B<--no-group>
+
+Do not display group column in the listing.
+
+=item B<--with-group>
+
+Display group column in the listing; the default option.
+
+=item B<-D>, B<--no-date>
+
+Do not display due date column in the listing.
+
+=item B<--with-date>
+
+Display due date column in the listing; the default option.
+
+=item B<-P>, B<--no-priority>
+
+Do not display priority column in the listing.
+
+=item B<--with-priority>
+
+Display priority column in the listing; the default option.
+
+=item B<-S>, B<--no-state>
+
+Do not display state column in the listing.
+
+=item B<--with-state>
+
+Display state column in the listing; the default option.
+
 =back
 
 =head1 ENVIRONMENT
@@ -1350,7 +1606,7 @@ directory of the w2do source package.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2008, 2009 Jaromir Hradilek
+Copyright (C) 2008, 2009, 2010 Jaromir Hradilek
 
 This program is free software; see the source for copying conditions. It is
 distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
